#!/usr/bin/perl -w

# gnupod-utils: utilities for GnuPod tunes database
# Copyright (C) 2002  Eric C. Cooper <ecc@cmu.edu>
# Released under the GNU General Public License

use strict;
use iPod;
use Getopt::Std;

sub usage() {
    die <<END_USAGE
Usage: $0 OPTIONS
Search GnuPod tunes database.

  -a ARTIST    print songs by ARTIST
  -l ALBUM     print songs from ALBUM
  -t TITLE     print songs with TITLE
  -i ID        print song with ID
  -n           print IDs only (useful with gnupod_delete)
  -m           iPod mountpoint, default is \$IPOD_MOUNTPOINT
  -h           print this summary and exit
END_USAGE
}

my %opt = ();
$opt{m} = $ENV{IPOD_MOUNTPOINT}; #defaulting
getopts('a:l:t:i:m:nh', \%opt) or usage();
usage() if !$opt{m} || $opt{h};

my %search = (artist => $opt{a},
	      album => $opt{l},
	      title => $opt{t},
	      id => $opt{i});

my $only_ids = $opt{n};

usage() unless grep(defined, values %search);

iPod::read_xml("$opt{m}/iPod_Control/.gnupod/GNUtunesDB");

unless ($only_ids) {
    printf "[ ";
    iPod::print_entry \*STDOUT, \%search;
    printf " ]\n";
}

SONG: for my $song (@$iPod::songs) {
    for my $tag (keys %search) {
	my $val = $search{$tag};
	next SONG if defined $val && !iPod::match($song, $tag, $val);
    }
    # if we reach here, song passes all the criteria
    if ($only_ids) {
	printf "%d\n", $song->{id};
    } else {
	iPod::print_song($song);
    }
}
